@@ -5,8 +5,8 @@ if (getRversion() >= "2.15.1") globalVariables("app")
 
 inline_generic <- function(app, x, style) {
   vec_style <- attr(x, "cli_style")
-  before <- vec_style$before %||% style$before
-  after <- vec_style$after %||% style$after
+  before <- call_if_fun(vec_style$before) %||% call_if_fun(style$before)
+  after <- call_if_fun(vec_style$after) %||% call_if_fun(style$after)
   fmt <- vec_style$fmt %||% style$fmt
   xx <- paste0(before, x, after)
   if (!is.null(fmt)) xx <- vcapply(xx, fmt)
@@ -89,7 +89,8 @@ inline_transformer <- local({
       .envir = envir,
       .transformer = inline_transformer,
       .open = paste0("{", envir$marker),
-      .close = paste0(envir$marker, "}")
+      .close = paste0(envir$marker, "}"),
+      .trim = TRUE
     )
 
     inline_collapse(
@@ -110,7 +111,8 @@ clii__inline <- function(app, text, .list) {
       .envir = t$values,
       .transformer = inline_transformer,
       .open = paste0("{", t$values$marker),
-      .close = paste0(t$values$marker, "}")
+      .close = paste0(t$values$marker, "}"),
+      .trim = TRUE
     )
   })
   paste(out, collapse = "")
@@ -156,7 +158,7 @@ make_cmd_transformer <- function(values) {
       funname <- captures[[1]]
       text <- captures[[2]]
 
-      out <- glue(text, .envir = envir, .transformer = sys.function())
+      out <- glue(text, .envir = envir, .transformer = sys.function(), .trim = TRUE)
       paste0("{", values$marker, ".", funname, " ", out, values$marker, "}")
     }
   }
@@ -166,7 +168,7 @@ glue_cmd <- function(..., .envir) {
   str <- paste0(unlist(list(...), use.names = FALSE), collapse = "")
   values <- new.env(parent = emptyenv())
   transformer <- make_cmd_transformer(values)
-  pstr <- glue(str, .envir = .envir, .transformer = transformer)
+  pstr <- glue(str, .envir = .envir, .transformer = transformer, .trim = TRUE)
   glue_delay(
     str = post_process_plurals(pstr, values),
     values = values
