@@ -3,6 +3,8 @@ package browse
 import (
 	"fmt"
 	"net/http"
+	"net/url"
+	"path"
 	"path/filepath"
 	"strconv"
 	"strings"
@@ -131,7 +133,7 @@ func runBrowse(opts *BrowseOptions) error {
 	if err != nil {
 		return err
 	}
-	url := ghrepo.GenerateRepoURL(baseRepo, section)
+	url := ghrepo.GenerateRepoURL(baseRepo, "%s", section)
 
 	if opts.NoBrowserFlag {
 		_, err := fmt.Fprintln(opts.IO.Out, url)
@@ -186,23 +188,30 @@ func parseSection(baseRepo ghrepo.Interface, opts *BrowseOptions) (string, error
 		} else {
 			rangeFragment = fmt.Sprintf("L%d", rangeStart)
 		}
-		return fmt.Sprintf("blob/%s/%s?plain=1#%s", branchName, filePath, rangeFragment), nil
+		return fmt.Sprintf("blob/%s/%s?plain=1#%s", escapePath(branchName), escapePath(filePath), rangeFragment), nil
 	}
-	return fmt.Sprintf("tree/%s/%s", branchName, filePath), nil
+	return strings.TrimSuffix(fmt.Sprintf("tree/%s/%s", escapePath(branchName), escapePath(filePath)), "/"), nil
+}
+
+// escapePath URL-encodes special characters but leaves slashes unchanged
+func escapePath(p string) string {
+	return strings.ReplaceAll(url.PathEscape(p), "%2F", "/")
 }
 
 func parseFile(opts BrowseOptions, f string) (p string, start int, end int, err error) {
+	if f == "" {
+		return
+	}
+
 	parts := strings.SplitN(f, ":", 3)
 	if len(parts) > 2 {
 		err = fmt.Errorf("invalid file argument: %q", f)
 		return
 	}
 
-	p = parts[0]
-	if !filepath.IsAbs(p) {
-		p = filepath.Clean(filepath.Join(opts.PathFromRepoRoot(), p))
-		// Ensure that a path using \ can be used in a URL
-		p = strings.ReplaceAll(p, "\\", "/")
+	p = filepath.ToSlash(parts[0])
+	if !path.IsAbs(p) {
+		p = path.Join(opts.PathFromRepoRoot(), p)
 		if p == "." || strings.HasPrefix(p, "..") {
 			p = ""
 		}
