@@ -2,6 +2,7 @@ package browse
 
 import (
 	"fmt"
+	"io/ioutil"
 	"net/http"
 	"os"
 	"path/filepath"
@@ -125,6 +126,8 @@ func TestNewCmdBrowse(t *testing.T) {
 			argv, err := shlex.Split(tt.cli)
 			assert.NoError(t, err)
 			cmd.SetArgs(argv)
+			cmd.SetOut(ioutil.Discard)
+			cmd.SetErr(ioutil.Discard)
 			_, err = cmd.ExecuteC()
 
 			if tt.wantsErr {
@@ -217,7 +220,7 @@ func Test_runBrowse(t *testing.T) {
 				Branch: "trunk",
 			},
 			baseRepo:    ghrepo.New("jlsestak", "CouldNotThinkOfARepoName"),
-			expectedURL: "https://github.com/jlsestak/CouldNotThinkOfARepoName/tree/trunk/",
+			expectedURL: "https://github.com/jlsestak/CouldNotThinkOfARepoName/tree/trunk",
 		},
 		{
 			name: "branch flag with file",
@@ -228,6 +231,35 @@ func Test_runBrowse(t *testing.T) {
 			baseRepo:    ghrepo.New("bchadwic", "LedZeppelinIV"),
 			expectedURL: "https://github.com/bchadwic/LedZeppelinIV/tree/trunk/main.go",
 		},
+		{
+			name: "branch flag within dir",
+			opts: BrowseOptions{
+				Branch:           "feature-123",
+				PathFromRepoRoot: func() string { return "pkg/dir" },
+			},
+			baseRepo:    ghrepo.New("bstnc", "yeepers"),
+			expectedURL: "https://github.com/bstnc/yeepers/tree/feature-123",
+		},
+		{
+			name: "branch flag within dir with .",
+			opts: BrowseOptions{
+				Branch:           "feature-123",
+				SelectorArg:      ".",
+				PathFromRepoRoot: func() string { return "pkg/dir" },
+			},
+			baseRepo:    ghrepo.New("bstnc", "yeepers"),
+			expectedURL: "https://github.com/bstnc/yeepers/tree/feature-123/pkg/dir",
+		},
+		{
+			name: "branch flag within dir with dir",
+			opts: BrowseOptions{
+				Branch:           "feature-123",
+				SelectorArg:      "inner/more",
+				PathFromRepoRoot: func() string { return "pkg/dir" },
+			},
+			baseRepo:    ghrepo.New("bstnc", "yeepers"),
+			expectedURL: "https://github.com/bstnc/yeepers/tree/feature-123/pkg/dir/inner/more",
+		},
 		{
 			name: "file with line number",
 			opts: BrowseOptions{
@@ -325,7 +357,7 @@ func Test_runBrowse(t *testing.T) {
 			},
 			baseRepo:    ghrepo.New("vilmibm", "gh-user-status"),
 			wantsErr:    false,
-			expectedURL: "https://github.com/vilmibm/gh-user-status/tree/6f1a2405cace1633d89a79c74c65f22fe78f9659/",
+			expectedURL: "https://github.com/vilmibm/gh-user-status/tree/6f1a2405cace1633d89a79c74c65f22fe78f9659",
 		},
 		{
 			name: "open last commit with a file",
@@ -363,6 +395,16 @@ func Test_runBrowse(t *testing.T) {
 			expectedURL:   "https://github.com/bchadwic/gh-graph/tree/trunk/pkg/cmd/pr",
 			wantsErr:      false,
 		},
+		{
+			name: "use special characters in selector arg",
+			opts: BrowseOptions{
+				SelectorArg: "?=hello world/ *:23-44",
+				Branch:      "branch/with spaces?",
+			},
+			baseRepo:    ghrepo.New("bchadwic", "test"),
+			expectedURL: "https://github.com/bchadwic/test/blob/branch/with%20spaces%3F/%3F=hello%20world/%20%2A?plain=1#L23-L44",
+			wantsErr:    false,
+		},
 	}
 
 	for _, tt := range tests {
@@ -410,67 +452,100 @@ func Test_runBrowse(t *testing.T) {
 }
 
 func Test_parsePathFromFileArg(t *testing.T) {
-	s := string(os.PathSeparator)
 	tests := []struct {
 		name         string
+		currentDir   string
 		fileArg      string
 		expectedPath string
 	}{
+		{
+			name:         "empty paths",
+			currentDir:   "",
+			fileArg:      "",
+			expectedPath: "",
+		},
+		{
+			name:         "root directory",
+			currentDir:   "",
+			fileArg:      ".",
+			expectedPath: "",
+		},
+		{
+			name:         "relative path",
+			currentDir:   "",
+			fileArg:      filepath.FromSlash("foo/bar.py"),
+			expectedPath: "foo/bar.py",
+		},
 		{
 			name:         "go to parent folder",
-			fileArg:      ".." + s,
+			currentDir:   "pkg/cmd/browse/",
+			fileArg:      filepath.FromSlash("../"),
 			expectedPath: "pkg/cmd",
 		},
 		{
 			name:         "current folder",
+			currentDir:   "pkg/cmd/browse/",
 			fileArg:      ".",
 			expectedPath: "pkg/cmd/browse",
 		},
 		{
 			name:         "current folder (alternative)",
-			fileArg:      "." + s,
+			currentDir:   "pkg/cmd/browse/",
+			fileArg:      filepath.FromSlash("./"),
 			expectedPath: "pkg/cmd/browse",
 		},
 		{
 			name:         "file that starts with '.'",
+			currentDir:   "pkg/cmd/browse/",
 			fileArg:      ".gitignore",
 			expectedPath: "pkg/cmd/browse/.gitignore",
 		},
 		{
 			name:         "file in current folder",
+			currentDir:   "pkg/cmd/browse/",
 			fileArg:      filepath.Join(".", "browse.go"),
 			expectedPath: "pkg/cmd/browse/browse.go",
 		},
 		{
 			name:         "file within parent folder",
+			currentDir:   "pkg/cmd/browse/",
 			fileArg:      filepath.Join("..", "browse.go"),
 			expectedPath: "pkg/cmd/browse.go",
 		},
 		{
 			name:         "file within parent folder uncleaned",
-			fileArg:      filepath.Join("..", ".") + s + s + s + "browse.go",
+			currentDir:   "pkg/cmd/browse/",
+			fileArg:      filepath.FromSlash(".././//browse.go"),
 			expectedPath: "pkg/cmd/browse.go",
 		},
 		{
 			name:         "different path from root directory",
+			currentDir:   "pkg/cmd/browse/",
 			fileArg:      filepath.Join("..", "..", "..", "internal/build/build.go"),
 			expectedPath: "internal/build/build.go",
 		},
 		{
 			name:         "go out of repository",
-			fileArg:      filepath.Join("..", "..", "..", "..", "..", "..") + s + "",
+			currentDir:   "pkg/cmd/browse/",
+			fileArg:      filepath.FromSlash("../../../../../../"),
 			expectedPath: "",
 		},
 		{
 			name:         "go to root of repository",
-			fileArg:      filepath.Join("..", "..", "..") + s + "",
+			currentDir:   "pkg/cmd/browse/",
+			fileArg:      filepath.Join("../../../"),
+			expectedPath: "",
+		},
+		{
+			name:         "empty fileArg",
+			fileArg:      "",
 			expectedPath: "",
 		},
 	}
 	for _, tt := range tests {
 		path, _, _, _ := parseFile(BrowseOptions{
 			PathFromRepoRoot: func() string {
-				return "pkg/cmd/browse/"
+				return tt.currentDir
 			}}, tt.fileArg)
 		assert.Equal(t, tt.expectedPath, path, tt.name)
 	}
