@@ -13,6 +13,8 @@ import (
 
 	"github.com/MakeNowJust/heredoc"
 	"github.com/cli/cli/v2/api"
+	"github.com/cli/cli/v2/context"
+	"github.com/cli/cli/v2/git"
 	"github.com/cli/cli/v2/internal/ghrepo"
 	"github.com/cli/cli/v2/internal/run"
 	"github.com/cli/cli/v2/pkg/cmd/pr/shared"
@@ -223,6 +225,16 @@ func runCommand(rt http.RoundTripper, branch string, isTTY bool, cli string) (*t
 		Branch: func() (string, error) {
 			return branch, nil
 		},
+		Remotes: func() (context.Remotes, error) {
+			return []*context.Remote{
+				{
+					Remote: &git.Remote{
+						Name: "origin",
+					},
+					Repo: ghrepo.New("OWNER", "REPO"),
+				},
+			}, nil
+		},
 	}
 
 	cmd := NewCmdMerge(factory, nil)
@@ -274,9 +286,11 @@ func TestPrMerge(t *testing.T) {
 			assert.NotContains(t, input, "commitHeadline")
 		}))
 
-	_, cmdTeardown := run.Stub()
+	cs, cmdTeardown := run.Stub()
 	defer cmdTeardown(t)
 
+	cs.Register(`git rev-parse --verify refs/heads/`, 0, "")
+
 	output, err := runCommand(http, "master", true, "pr merge 1 --merge")
 	if err != nil {
 		t.Fatalf("error running command `pr merge`: %v", err)
@@ -343,9 +357,11 @@ func TestPrMerge_nontty(t *testing.T) {
 			assert.NotContains(t, input, "commitHeadline")
 		}))
 
-	_, cmdTeardown := run.Stub()
+	cs, cmdTeardown := run.Stub()
 	defer cmdTeardown(t)
 
+	cs.Register(`git rev-parse --verify refs/heads/`, 0, "")
+
 	output, err := runCommand(http, "master", false, "pr merge 1 --merge")
 	if err != nil {
 		t.Fatalf("error running command `pr merge`: %v", err)
@@ -428,6 +444,7 @@ func TestPrMerge_deleteBranch(t *testing.T) {
 	cs.Register(`git checkout master`, 0, "")
 	cs.Register(`git rev-parse --verify refs/heads/blueberries`, 0, "")
 	cs.Register(`git branch -D blueberries`, 0, "")
+	cs.Register(`git pull --ff-only`, 0, "")
 
 	output, err := runCommand(http, "blueberries", true, `pr merge --merge --delete-branch`)
 	if err != nil {
@@ -515,6 +532,7 @@ func Test_nonDivergingPullRequest(t *testing.T) {
 	defer cmdTeardown(t)
 
 	cs.Register(`git .+ show .+ HEAD`, 0, "COMMITSHA1,title")
+	cs.Register(`git rev-parse --verify refs/heads/`, 0, "")
 
 	output, err := runCommand(http, "blueberries", true, "pr merge --merge")
 	if err != nil {
@@ -554,6 +572,7 @@ func Test_divergingPullRequestWarning(t *testing.T) {
 	defer cmdTeardown(t)
 
 	cs.Register(`git .+ show .+ HEAD`, 0, "COMMITSHA2,title")
+	cs.Register(`git rev-parse --verify refs/heads/`, 0, "")
 
 	output, err := runCommand(http, "blueberries", true, "pr merge --merge")
 	if err != nil {
@@ -590,9 +609,11 @@ func Test_pullRequestWithoutCommits(t *testing.T) {
 			assert.NotContains(t, input, "commitHeadline")
 		}))
 
-	_, cmdTeardown := run.Stub()
+	cs, cmdTeardown := run.Stub()
 	defer cmdTeardown(t)
 
+	cs.Register(`git rev-parse --verify refs/heads/`, 0, "")
+
 	output, err := runCommand(http, "blueberries", true, "pr merge --merge")
 	if err != nil {
 		t.Fatalf("error running command `pr merge`: %v", err)
@@ -627,9 +648,11 @@ func TestPrMerge_rebase(t *testing.T) {
 			assert.NotContains(t, input, "commitHeadline")
 		}))
 
-	_, cmdTeardown := run.Stub()
+	cs, cmdTeardown := run.Stub()
 	defer cmdTeardown(t)
 
+	cs.Register(`git rev-parse --verify refs/heads/`, 0, "")
+
 	output, err := runCommand(http, "master", true, "pr merge 2 --rebase")
 	if err != nil {
 		t.Fatalf("error running command `pr merge`: %v", err)
@@ -666,9 +689,11 @@ func TestPrMerge_squash(t *testing.T) {
 			assert.NotContains(t, input, "commitHeadline")
 		}))
 
-	_, cmdTeardown := run.Stub()
+	cs, cmdTeardown := run.Stub()
 	defer cmdTeardown(t)
 
+	cs.Register(`git rev-parse --verify refs/heads/`, 0, "")
+
 	output, err := runCommand(http, "master", true, "pr merge 3 --squash")
 	if err != nil {
 		t.Fatalf("error running command `pr merge`: %v", err)
@@ -703,6 +728,7 @@ func TestPrMerge_alreadyMerged(t *testing.T) {
 	cs.Register(`git checkout master`, 0, "")
 	cs.Register(`git rev-parse --verify refs/heads/blueberries`, 0, "")
 	cs.Register(`git branch -D blueberries`, 0, "")
+	cs.Register(`git pull --ff-only`, 0, "")
 
 	as, surveyTeardown := prompt.InitAskStubber()
 	defer surveyTeardown()
@@ -730,9 +756,11 @@ func TestPrMerge_alreadyMerged_nonInteractive(t *testing.T) {
 		baseRepo("OWNER", "REPO", "master"),
 	)
 
-	_, cmdTeardown := run.Stub()
+	cs, cmdTeardown := run.Stub()
 	defer cmdTeardown(t)
 
+	cs.Register(`git rev-parse --verify refs/heads/`, 0, "")
+
 	output, err := runCommand(http, "blueberries", true, "pr merge 4 --merge")
 	if err != nil {
 		t.Fatalf("Got unexpected error running `pr merge` %s", err)
@@ -774,9 +802,11 @@ func TestPRMerge_interactive(t *testing.T) {
 			assert.NotContains(t, input, "commitHeadline")
 		}))
 
-	_, cmdTeardown := run.Stub()
+	cs, cmdTeardown := run.Stub()
 	defer cmdTeardown(t)
 
+	cs.Register(`git rev-parse --verify refs/heads/blueberries`, 0, "")
+
 	as, surveyTeardown := prompt.InitAskStubber()
 	defer surveyTeardown()
 
@@ -834,6 +864,7 @@ func TestPRMerge_interactiveWithDeleteBranch(t *testing.T) {
 	cs.Register(`git checkout master`, 0, "")
 	cs.Register(`git rev-parse --verify refs/heads/blueberries`, 0, "")
 	cs.Register(`git branch -D blueberries`, 0, "")
+	cs.Register(`git pull --ff-only`, 0, "")
 
 	as, surveyTeardown := prompt.InitAskStubber()
 	defer surveyTeardown()
@@ -932,9 +963,11 @@ func TestPRMerge_interactiveCancelled(t *testing.T) {
 			"squashMergeAllowed": true
 		} } }`))
 
-	_, cmdTeardown := run.Stub()
+	cs, cmdTeardown := run.Stub()
 	defer cmdTeardown(t)
 
+	cs.Register(`git rev-parse --verify refs/heads/`, 0, "")
+
 	as, surveyTeardown := prompt.InitAskStubber()
 	defer surveyTeardown()
 
