@@ -10,7 +10,7 @@ test_that("sitrep runs", {
 
 test_that("get_active_symbol_set", {
   withr::with_options(list(cli.unicode = TRUE), {
-    expect_equal(get_active_symbol_set(), "UTF-8")
+    expect_true(get_active_symbol_set() %in% c("UTF-8", "RStudio (UTF-8)"))
   })
   withr::with_options(list(cli.unicode = FALSE), {
     set <- get_active_symbol_set()
